LIGHTKURVE_CITATION ASTROPY_CITATION ASTROQUERY_CITATION @MISC{2019ascl.soft05007B, author = {{Brasseur}, C.~E. and {Phillip}, Carlita and {Fleming}, Scott W. and {Mullally}, S.~E. and {White}, Richard L.}, title = "{Astrocut: Tools for creating cutouts of TESS images}", keywords = {Software}, year = 2019, month = may, eid = {ascl:1905.007}, pages = {ascl:1905.007}, archivePrefix = {ascl}, eprint = {1905.007}, adsurl = {https://ui.adsabs.harvard.edu/abs/2019ascl.soft05007B}, adsnote = {Provided by the SAO/NASA Astrophysics Data System} }

When using Lightkurve, we kindly request that you cite the following packages:

- lightkurve
- astropy
- astroquery
  — if you are using search_lightcurve() or search_targetpixelfile().
- tesscut
  — if you are using search_tesscut().